@@ -2,17 +2,43 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Author;
 # ABSTRACT: An Author data object
-$MetaCPAN::Client::Author::VERSION = '1.021000';
+$MetaCPAN::Client::Author::VERSION = '1.022001';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
 
-my @known_fields = qw<
-    blog city country dir email gravatar_url links name
-    pauseid profile release_count updated user website
->;
+my %known_fields = (
+    scalar => [qw<
+        city
+        country
+        dir
+        gravatar_url
+        name
+        pauseid
+        region
+        updated
+        user
+    >],
 
-foreach my $field (@known_fields) {
+    arrayref => [qw<
+        donation
+        email
+        profile
+        website
+    >],
+
+    hashref => [qw<
+        blog
+        extra
+        links
+        release_count
+    >],
+);
+
+my @known_fields =
+    map { @{ $known_fields{$_} } } qw< scalar arrayref hashref >;
+
+foreach my $field ( @known_fields ) {
     has $field => (
         is      => 'ro',
         lazy    => 1,
@@ -23,7 +49,7 @@ foreach my $field (@known_fields) {
     );
 }
 
-sub _known_fields { return \@known_fields }
+sub _known_fields { \%known_fields }
 
 sub releases {
     my $self = shift;
@@ -51,78 +77,95 @@ MetaCPAN::Client::Author - An Author data object
 
 =head1 VERSION
 
-version 1.021000
+version 1.022001
+
+=head1 SYNOPSIS
+
+my $author = $mcpan->author('MICKEY');
 
 =head1 DESCRIPTION
 
-    my $author = $mcpan->author('MICKEY');
-
-This represents a MetaCPAN author entity.
+a MetaCPAN author entity object.
 
 =head1 ATTRIBUTES
 
-=head2 name
-
-Author name.
-
 =head2 pauseid
 
-Author PAUSE ID.
-
-=head2 email
-
-Author's Email.
-
-=head2 blog
-
-Array of author's blog addresses.
-
-Example:
-
-    [
-        {
-            url  => "http://blogs.perl.org/users/brian_d_foy/"
-            feed => "http://blogs.perl.org/users/brian_d_foy/atom.xml",
-        }
-    ]
+=head2 name
 
 =head2 city
 
-Author's city.
-
 =head2 country
 
-Author's country.
+=head2 region
+
+=head2 updated
 
 =head2 dir
 
-Author's directory of distribution and files.
+Directory of distribution and files.
 
-Example: C<< id/P/PE/PERLER >>
+e.g. C<< id/P/PE/PERLER >>
 
 =head2 gravatar_url
 
-Author's Gravatar.com user picture URL. This URL is generated using
-PAUSEID@cpan.org.
+Gravatar.com user picture URL.
+
+This URL is generated using PAUSEID@cpan.org.
+
+=head2 user
+
+Identification code.
+
+=head2 donation
+
+Array-Ref.
+
+=head2 email
+
+Array-Ref.
+
+=head2 website
+
+Array-Ref.
 
 =head2 profile
 
-Array of author's user profiles.
-
-Example:
+Array-Ref.
 
+e.g.
     [
         { name => "amazon",        id => "B002MRC39U"  },
         { name => "stackoverflow", id => "brian-d-foy" },
     ]
 
-=head2 website
+=head2 links
 
-Array of Author's websites.
+Hash-Ref.
 
-=head2 updated
+=head2 extra
 
-=head2 user
+Hash-Ref.
+
+=head2 blog
+
+Hash-Ref.
+
+  {
+    url  => "http://blogs.perl.org/users/brian_d_foy/"
+    feed => "http://blogs.perl.org/users/brian_d_foy/atom.xml",
+  }
+
+=head2 release_count
+
+Hash-Ref.
+
+e.g.
+   {
+      latest       => 118,
+      backpan-only => 558,
+      cpan         => 18,
+   }
 
 =head1 METHODS
 
