@@ -2,12 +2,19 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Distribution;
 # ABSTRACT: A Distribution data object
-$MetaCPAN::Client::Distribution::VERSION = '1.021000';
+$MetaCPAN::Client::Distribution::VERSION = '1.022001';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
 
-my @known_fields = qw<name bugs>;
+my %known_fields = (
+    scalar   => [qw< name >],
+    arrayref => [],
+    hashref  => [qw< bugs river >]
+);
+
+my @known_fields =
+    map { @{ $known_fields{$_} } } qw< scalar arrayref hashref >;
 
 foreach my $field (@known_fields) {
     has $field => (
@@ -20,8 +27,7 @@ foreach my $field (@known_fields) {
     );
 }
 
-sub _known_fields { return \@known_fields }
-
+sub _known_fields { return \%known_fields }
 
 1;
 
@@ -37,23 +43,27 @@ MetaCPAN::Client::Distribution - A Distribution data object
 
 =head1 VERSION
 
-version 1.021000
+version 1.022001
+
+=head1 SYNOPSIS
+
+my $dist = $mcpan->distribution('MetaCPAN-Client');
 
 =head1 DESCRIPTION
 
-    my $dist = $mcpan->distribution('MetaCPAN-Client');
-
-This represents a MetaCPAN distribution entity.
+A MetaCPAN distribution entity object.
 
 =head1 ATTRIBUTES
 
 =head2 name
 
-Distribution's name.
-
 =head2 bugs
 
-Distribution's bug information.
+Hash-Ref.
+
+=head2 river
+
+Hash-Ref.
 
 =head1 AUTHORS
 
