@@ -2,14 +2,19 @@ use strict;
 use warnings;
 package MetaCPAN::Client::DownloadURL;
 # ABSTRACT: A Download URL data object
-$MetaCPAN::Client::DownloadURL::VERSION = '1.021000';
+$MetaCPAN::Client::DownloadURL::VERSION = '1.022001';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
 
-my @known_fields = qw<
-    date download_url status version
->;
+my %known_fields = (
+    scalar   => [qw< date download_url status version >],
+    arrayref => [],
+    hashref  => [],
+);
+
+my @known_fields =
+    map { @{ $known_fields{$_} } } qw< scalar arrayref hashref >;
 
 foreach my $field (@known_fields) {
     has $field => (
@@ -22,7 +27,7 @@ foreach my $field (@known_fields) {
     );
 }
 
-sub _known_fields { return \@known_fields }
+sub _known_fields { return \%known_fields }
 
 1;
 
@@ -38,10 +43,18 @@ MetaCPAN::Client::DownloadURL - A Download URL data object
 
 =head1 VERSION
 
-version 1.021000
+version 1.022001
+
+=head1 SYNOPSIS
+
+my $download_url = $mcpan->download_url('Moose');
 
 =head1 DESCRIPTION
 
+A MetaCPAN download_url entiry object.
+
+Supported for MetaCPAN v1 only.
+
 =head1 ATTRIBUTES
 
 =head2 date
