@@ -2,12 +2,19 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Favorite;
 # ABSTRACT: A Favorite data object
-$MetaCPAN::Client::Favorite::VERSION = '1.021000';
+$MetaCPAN::Client::Favorite::VERSION = '1.022001';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
 
-my @known_fields = qw<date user release id author distribution>;
+my %known_fields = (
+    scalar   => [qw< date user release id author distribution >],
+    arrayref => [],
+    hashref  => []
+);
+
+my @known_fields =
+    map { @{ $known_fields{$_} } } qw< scalar arrayref hashref >;
 
 foreach my $field (@known_fields) {
     has $field => (
@@ -20,8 +27,7 @@ foreach my $field (@known_fields) {
     );
 }
 
-sub _known_fields { return \@known_fields }
-
+sub _known_fields { return \%known_fields }
 
 1;
 
@@ -37,15 +43,17 @@ MetaCPAN::Client::Favorite - A Favorite data object
 
 =head1 VERSION
 
-version 1.021000
+version 1.022001
+
+=head1 SYNOPSIS
+
+my $favorite = $mcpan->favorite( {
+    distribution => 'Moose'
+} );
 
 =head1 DESCRIPTION
 
-    my $favorite = $mcpan->favorite( {
-        distribution => 'Moose'
-    } );
-
-This represents a MetaCPAN favorite entity.
+A MetaCPAN favorite entity object.
 
 =head1 ATTRIBUTES
 
