@@ -2,18 +2,46 @@ use strict;
 use warnings;
 package MetaCPAN::Client::File;
 # ABSTRACT: A File data object
-$MetaCPAN::Client::File::VERSION = '1.021000';
+$MetaCPAN::Client::File::VERSION = '1.022001';
 use Moo;
 use Carp;
 
 with 'MetaCPAN::Client::Role::Entity';
 
-my @known_fields = qw<
-    status date author maturity directory indexed documentation id
-    module authorized pod_lines version binary name version_numified release
-    path description stat distribution level sloc abstract slop mime
-    download_url
->;
+my %known_fields = (
+    scalar => [qw<
+        abstract
+        author
+        authorized
+        binary
+        date
+        description
+        directory
+        distribution
+        documentation
+        download_url
+        id
+        indexed
+        level
+        maturity
+        mime
+        name
+        path
+        release
+        sloc
+        slop
+        status
+        version
+        version_numified
+    >],
+
+    arrayref => [qw< module pod_lines >],
+
+    hashref  => [qw< stat >],
+);
+
+my @known_fields =
+    map { @{ $known_fields{$_} } } qw< scalar arrayref hashref >;
 
 foreach my $field (@known_fields) {
     has $field => (
@@ -26,7 +54,7 @@ foreach my $field (@known_fields) {
     );
 }
 
-sub _known_fields { return \@known_fields }
+sub _known_fields { return \%known_fields }
 
 sub pod {
     my $self   = shift;
@@ -61,7 +89,6 @@ sub source {
         );
 }
 
-
 1;
 
 __END__
@@ -76,10 +103,12 @@ MetaCPAN::Client::File - A File data object
 
 =head1 VERSION
 
-version 1.021000
+version 1.022001
 
 =head1 DESCRIPTION
 
+A MetaCPAN file entity object.
+
 =head1 ATTRIBUTES
 
 =head2 status
@@ -98,12 +127,8 @@ version 1.021000
 
 =head2 id
 
-=head2 module
-
 =head2 authorized
 
-=head2 pod_lines
-
 =head2 version
 
 =head2 binary
@@ -118,8 +143,6 @@ version 1.021000
 
 =head2 description
 
-=head2 stat
-
 =head2 distribution
 
 =head2 level
@@ -132,6 +155,18 @@ version 1.021000
 
 =head2 mime
 
+=head2 module
+
+Array-Ref.
+
+=head2 pod_lines
+
+Array-Ref.
+
+=head2 stat
+
+Hash-Ref.
+
 =head1 METHODS
 
 =head2 pod
