@@ -2,16 +2,42 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Mirror;
 # ABSTRACT: A Mirror data object
-$MetaCPAN::Client::Mirror::VERSION = '1.021000';
+$MetaCPAN::Client::Mirror::VERSION = '1.022001';
 use Moo;
 use Carp;
 
 with 'MetaCPAN::Client::Role::Entity';
 
-my @known_fields = qw< name org ftp contact city rsync src ccode
-                       aka_name tz note dnsrr region inceptdate
-                       country location freq continent http
-                       reitredate A_or_CNAME >;
+my %known_fields = (
+    scalar => [qw<
+        aka_name
+        A_or_CNAME
+        ccode
+        city
+        continent
+        country
+        dnsrr
+        freq
+        ftp
+        http
+        inceptdate
+        name
+        note
+        org
+        region
+        reitredate
+        rsync
+        src
+        tz
+    >],
+
+    arrayref => [qw< contact location >],
+
+    hashref  => [qw<>],
+);
+
+my @known_fields =
+    map { @{ $known_fields{$_} } } qw< scalar arrayref hashref >;
 
 foreach my $field (@known_fields) {
     has $field => (
@@ -24,8 +50,7 @@ foreach my $field (@known_fields) {
     );
 }
 
-sub _known_fields { return \@known_fields }
-
+sub _known_fields { return \%known_fields }
 
 1;
 
@@ -41,13 +66,17 @@ MetaCPAN::Client::Mirror - A Mirror data object
 
 =head1 VERSION
 
-version 1.021000
+version 1.022001
 
-=head1 
-DESCRIPTION
+=head1 SYNOPSIS
 
-=head1 
-ATTRIBUTES
+my $mirror = $mcpan->mirror('eutelia.it');
+
+=head1 DESCRIPTION
+
+A MetaCPAN mirror entity object.
+
+=head1 ATTRIBUTES
 
 =head2 name
 
@@ -55,8 +84,6 @@ ATTRIBUTES
 
 =head2 ftp
 
-=head2 contact
-
 =head2 city
 
 =head2 rsync
@@ -79,8 +106,6 @@ ATTRIBUTES
 
 =head2 country
 
-=head2 location
-
 =head2 freq
 
 =head2 continent
@@ -91,7 +116,13 @@ ATTRIBUTES
 
 =head2 A_or_CNAME
 
-=head1 METHODS
+=head2 contact
+
+Array-Ref.
+
+=head2 location
+
+Array-Ref.
 
 =head1 AUTHORS
 
