@@ -2,15 +2,28 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Rating;
 # ABSTRACT: A Rating data object
-$MetaCPAN::Client::Rating::VERSION = '1.021000';
+$MetaCPAN::Client::Rating::VERSION = '1.022001';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
 
-my @known_fields = qw<
-    date release author details
-    rating distribution helpful user
->;
+my %known_fields = (
+    scalar => [qw<
+        author
+        date
+        details
+        distribution
+        helpful
+        rating
+        release
+        user
+    >],
+    arrayref => [],
+    hashref  => [],
+);
+
+my @known_fields =
+    map { @{ $known_fields{$_} } } qw< scalar arrayref hashref >;
 
 foreach my $field (@known_fields) {
     has $field => (
@@ -23,7 +36,7 @@ foreach my $field (@known_fields) {
     );
 }
 
-sub _known_fields { return \@known_fields }
+sub _known_fields { return \%known_fields }
 
 1;
 
@@ -39,10 +52,16 @@ MetaCPAN::Client::Rating - A Rating data object
 
 =head1 VERSION
 
-version 1.021000
+version 1.022001
+
+=head1 SYNOPSIS
+
+my $rating = $mcpan->rating({ distribution => "Moo" });
 
 =head1 DESCRIPTION
 
+A MetaCPAN rating entity object.
+
 =head1 ATTRIBUTES
 
 =head2 date
