@@ -2,16 +2,45 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Release;
 # ABSTRACT: A Release data object
-$MetaCPAN::Client::Release::VERSION = '1.021000';
+$MetaCPAN::Client::Release::VERSION = '1.022001';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
 
-my @known_fields = qw<
-    resources status date author maturity dependency id authorized
-    download_url first archive version name version_numified license
-    distribution stat provides tests abstract metadata
->;
+my %known_fields = (
+    scalar => [qw<
+        abstract
+        archive
+        author
+        authorized
+        date
+        distribution
+        download_url
+        first
+        id
+        maturity
+        name
+        status
+        version
+        version_numified
+    >],
+
+    arrayref => [qw<
+        dependency
+        license
+        provides
+    >],
+
+    hashref => [qw<
+        metadata
+        resources
+        stat
+        tests
+    >],
+);
+
+my @known_fields =
+    map { @{ $known_fields{$_} } } qw< scalar arrayref hashref >;
 
 foreach my $field (@known_fields) {
     has $field => (
@@ -24,7 +53,7 @@ foreach my $field (@known_fields) {
     );
 }
 
-sub _known_fields { return \@known_fields }
+sub _known_fields { return \%known_fields }
 
 1;
 
@@ -40,13 +69,17 @@ MetaCPAN::Client::Release - A Release data object
 
 =head1 VERSION
 
-version 1.021000
+version 1.022001
+
+=head1 SYNOPSIS
+
+my $release = $mcpan->release('Moose');
 
 =head1 DESCRIPTION
 
-=head1 ATTRIBUTES
+A MetaCPAN release entity object.
 
-=head2 resources
+=head1 ATTRIBUTES
 
 =head2 status
 
@@ -56,8 +89,6 @@ version 1.021000
 
 =head2 maturity
 
-=head2 dependency
-
 =head2 id
 
 =head2 authorized
@@ -74,20 +105,38 @@ version 1.021000
 
 =head2 version_numified
 
-=head2 license
-
 =head2 distribution
 
-=head2 stat
-
-=head2 provides
-
-=head2 tests
-
 =head2 abstract
 
+=head2 dependency
+
+Array-Ref.
+
+=head2 license
+
+Array-Ref.
+
+=head2 provides
+
+Array-Ref.
+
 =head2 metadata
 
+Hash-Ref.
+
+=head2 resources
+
+Hash-Ref.
+
+=head2 stat
+
+Hash-Ref.
+
+=head2 tests
+
+Hash-Ref.
+
 =head1 AUTHORS
 
 =over 4
