@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '1.021000';
+$MetaCPAN::Client::Request::VERSION = '1.022001';
 use Moo;
 use Carp;
 use JSON::MaybeXS qw<decode_json encode_json>;
@@ -59,13 +59,19 @@ has _is_agg => (
 
 sub _build_ua {
     my $self = shift;
+
     # This level of indirection is so that if a user has not specified a custom UA
     # MetaCPAN::Client and ElasticSearch will have their own UA's
     #
     # But if the user **has** specified a custom UA, that UA is used for both.
     if ( $self->_has_user_ua ) {
-      return $self->_user_ua;
+        my $ua = $self->_user_ua;
+        croak "cannot use given ua (must support 'get' and 'post' methods)"
+            unless $ua->can("get") and $ua->can("post");
+
+        return $self->_user_ua;
     }
+
     return HTTP::Tiny->new( @{ $self->ua_args } );
 }
 
@@ -252,7 +258,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 1.021000
+version 1.022001
 
 =head1 ATTRIBUTES
 
